Header menu logo Nao

AgentGroup Module

Functions and values

Function or value Description

create agents termination

Full Usage: create agents termination

Parameters:
Returns: AgentGroup

Create a group with agents and a termination condition

agents : IAgent list
termination : TerminationCondition
Returns: AgentGroup

createModerated agents moderator termination

Full Usage: createModerated agents moderator termination

Parameters:
Returns: AgentGroup

Create a moderated group where a moderator coordinates turns

agents : IAgent list
moderator : IAgent
termination : TerminationCondition
Returns: AgentGroup

runAsync input group

Full Usage: runAsync input group

Parameters:
Returns: Task<AgentMessage list>

Run a collaborative conversation starting with an initial input

input : string
group : AgentGroup
Returns: Task<AgentMessage list>

shouldTerminate history group

Full Usage: shouldTerminate history group

Parameters:
Returns: bool

Check if the conversation should terminate

history : AgentMessage list
group : AgentGroup
Returns: bool

Type something to start searching.