LifecycleState Type
Agent lifecycle states following a state-machine model
Union cases
| Union case |
Description
|
Full Usage:
Completed
|
Agent completed its task successfully |
Full Usage:
Created
|
Agent has been created but not yet initialized |
Full Usage:
Failed error
Parameters:
string
|
Agent encountered a fatal error
|
Full Usage:
Ready
|
Agent is initialized and ready to accept work |
Full Usage:
Running
|
Agent is currently executing a task |
Full Usage:
Suspended
|
Agent execution is paused (can be resumed) |
Full Usage:
Terminated
|
Agent was explicitly terminated |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsCompleted
Returns: bool
|
|
Full Usage:
this.IsCreated
Returns: bool
|
|
Full Usage:
this.IsFailed
Returns: bool
|
|
Full Usage:
this.IsReady
Returns: bool
|
|
Full Usage:
this.IsRunning
Returns: bool
|
|
Full Usage:
this.IsSuspended
Returns: bool
|
|
Full Usage:
this.IsTerminated
Returns: bool
|
|
Nao