Header menu logo Nao

Pipeline Module

Functions and values

Function or value Description

create stages

Full Usage: create stages

Parameters:
Returns: Pipeline

Create a pipeline from an ordered list of agents

stages : IAgent list
Returns: Pipeline

runAsync input pipeline

Full Usage: runAsync input pipeline

Parameters:
Returns: Task<string>

Run input through all stages sequentially, passing each output to the next

input : string
pipeline : Pipeline
Returns: Task<string>

Type something to start searching.