Header menu logo Nao

Policy Type

A governance policy that can be enforced at runtime

Record fields

Record Field Description

Description

Full Usage: Description

Field type: string

Human-readable description

Field type: string

Enforcement

Full Usage: Enforcement

Field type: PolicyEnforcement

The enforcement action

Field type: PolicyEnforcement

Evaluate

Full Usage: Evaluate

Field type: PolicyContext -> string option

The check function: returns None if policy passes, Some error message if violated

Field type: PolicyContext -> string option

Id

Full Usage: Id

Field type: string

Policy identifier

Field type: string

Type something to start searching.