costBudgetPolicy maxUsd
decimal
Policy
Cost budget policy: blocks when estimated cost exceeds budget
create policies
Policy list
PolicyEngine
Create a policy engine from a list of policies
maxOutputLengthPolicy maxChars
int
Content length policy: blocks excessively long outputs
rateLimitPolicy capability maxPerMinute
string
Rate limit policy: blocks when too many actions in a time window
Type something to start searching.