Header menu logo Nao

Router Module

Functions and values

Function or value Description

create agents strategy

Full Usage: create agents strategy

Parameters:
Returns: Router

Create a router with a list of agents and a strategy

agents : IAgent list
strategy : RoutingStrategy
Returns: Router

findAgent name router

Full Usage: findAgent name router

Parameters:
    name : string
    router : Router

Returns: IAgent option

Find an agent by name

name : string
router : Router
Returns: IAgent option

routeAsync input router

Full Usage: routeAsync input router

Parameters:
    input : string
    router : Router

Returns: Task<string>

Route input to an agent and return its response

input : string
router : Router
Returns: Task<string>

Type something to start searching.