Header menu logo Nao

ToolComposition Type

A composed tool that chains, parallelizes, or conditionally routes between tools

Union cases

Union case Description

Adaptive(step, router)

Full Usage: Adaptive(step, router)

Parameters:

Execute a tool, then use an LLM to decide the next step

step : ToolStep
router : string -> Task<ToolStep option>

Chain steps

Full Usage: Chain steps

Parameters:

Execute tools sequentially, passing output of one as input to next

steps : ToolStep list

Conditional(condition, branches)

Full Usage: Conditional(condition, branches)

Parameters:
    condition : string -> string
    branches : Map<string, ToolStep>

Execute one of several tools based on a condition

condition : string -> string
branches : Map<string, ToolStep>

Fallback(primary, fallback)

Full Usage: Fallback(primary, fallback)

Parameters:

Execute a tool and if it fails, try the fallback

primary : ToolStep
fallback : ToolStep

Parallel steps

Full Usage: Parallel steps

Parameters:

Execute tools in parallel and collect all results

steps : ToolStep list

Instance members

Instance member Description

this.IsAdaptive

Full Usage: this.IsAdaptive

Returns: bool
Returns: bool

this.IsChain

Full Usage: this.IsChain

Returns: bool
Returns: bool

this.IsConditional

Full Usage: this.IsConditional

Returns: bool
Returns: bool

this.IsFallback

Full Usage: this.IsFallback

Returns: bool
Returns: bool

this.IsParallel

Full Usage: this.IsParallel

Returns: bool
Returns: bool

Type something to start searching.