Header menu logo Nao

Body Type

 The document body: the single switch between the two fundamental document shapes.

 * `Fluid`  — reflowable content (text / markdown / html). Paginated *targets*
   auto-break it into pages using `Document.DefaultPage`.
 * `Paged`  — fixed pages / slides (pdf / word-as-laid-out / ppt). Fluid *targets*
   flatten the pages back into a single content stream.

Union cases

Union case Description

Fluid Block list

Full Usage: Fluid Block list

Parameters:
Item : Block list

Paged Page list

Full Usage: Paged Page list

Parameters:
Item : Page list

Instance members

Instance member Description

this.IsFluid

Full Usage: this.IsFluid

Returns: bool
Returns: bool

this.IsPaged

Full Usage: this.IsPaged

Returns: bool
Returns: bool

Type something to start searching.