Header menu logo Nao

Placement Type

Per-child placement hints, interpreted according to the parent `Layout`. Fields irrelevant to the active layout are simply ignored.

Record fields

Record Field Description

AlignSelf

Full Usage: AlignSelf

Field type: Align option

Cross-axis self-alignment override.

Field type: Align option

Basis

Full Usage: Basis

Field type: Length option
Field type: Length option

Column

Full Usage: Column

Field type: int option

1-based grid column the child starts in.

Field type: int option

ColumnSpan

Full Usage: ColumnSpan

Field type: int option
Field type: int option

Grow

Full Usage: Grow

Field type: float option
Field type: float option

Order

Full Usage: Order

Field type: int option
Field type: int option

Rect

Full Usage: Rect

Field type: Rect option

Explicit rectangle within the container (absolute layout only).

Field type: Rect option

Row

Full Usage: Row

Field type: int option

1-based grid row the child starts in.

Field type: int option

RowSpan

Full Usage: RowSpan

Field type: int option
Field type: int option

Shrink

Full Usage: Shrink

Field type: float option
Field type: float option

Static members

Static member Description

Placement.At(rect)

Full Usage: Placement.At(rect)

Parameters:
Returns: Placement

Place a child at an absolute rectangle.

rect : Rect
Returns: Placement

Placement.Cell(column, row, ?columnSpan, ?rowSpan)

Full Usage: Placement.Cell(column, row, ?columnSpan, ?rowSpan)

Parameters:
    column : int
    row : int
    ?columnSpan : int
    ?rowSpan : int

Returns: Placement

Place a child in a grid cell with an optional span.

column : int
row : int
?columnSpan : int
?rowSpan : int
Returns: Placement

Placement.None

Full Usage: Placement.None

Returns: Placement

No placement hints — let the layout default-position the child.

Returns: Placement

Type something to start searching.