AdoAuditLog Type
ADO.NET-backed IAuditLog. The AuditAction/PermissionLevel unions are encoded to text columns so the schema stays portable across providers.
Constructors
| Constructor |
Description
|
|
|
ADO.NET-backed IAuditLog. The AuditAction/PermissionLevel unions are encoded to text columns so the schema stays portable across providers.
| Constructor |
Description
|
|
|