Header menu logo Nao

PersistentTracer Type

Event-sourced ITracer. Span identifiers are generated internally, so this is a self-contained implementation (mirroring InMemoryTracer) that persists each span upsert as a full span snapshot and rebuilds the span table on load.

Constructors

Constructor Description

PersistentTracer(store)

Full Usage: PersistentTracer(store)

Parameters:
Returns: PersistentTracer
store : IEventStore
Returns: PersistentTracer

Type something to start searching.