OllamaProvider Type
LLM provider that connects to an Ollama server via its OpenAI-compatible API. Ollama exposes /v1/chat/completions for chat-style completions.
Constructors
| Constructor |
Description
|
|
|
LLM provider that connects to an Ollama server via its OpenAI-compatible API. Ollama exposes /v1/chat/completions for chat-style completions.
| Constructor |
Description
|
|
|