Header menu logo Nao

WorkspaceRegistry Type

In-memory workspace registry backed by a concurrent dictionary. Designed to be registered as a singleton in the Orleans DI container.

Constructors

Constructor Description

WorkspaceRegistry()

Full Usage: WorkspaceRegistry()

Returns: WorkspaceRegistry

Instance members

Instance member Description

this.Register

Full Usage: this.Register

Parameters:

Register a workspace with an optional source path for reload support

id : WorkspaceId
defs : WorkspaceDefinitions
?sourcePath : string

Type something to start searching.