Policy Type
A governance policy that can be enforced at runtime
Record fields
| Record Field |
Description
|
Full Usage:
Description
Field type: string
|
Human-readable description
|
|
The enforcement action
|
|
The check function: returns None if policy passes, Some error message if violated
|
Full Usage:
Id
Field type: string
|
Policy identifier
|
Nao