Prompt Type
A structured prompt definition following prompt engineering best practices
Record fields
| Record Field |
Description
|
Full Usage:
Constraints
Field type: string list
|
Constraints and rules the agent must follow
|
Full Usage:
Context
Field type: string list
|
Additional context injected at runtime (e.g. retrieved documents)
|
Full Usage:
DomainKnowledge
Field type: string list
|
Domain-specific knowledge and context the agent needs
|
|
Few-shot examples demonstrating expected behavior
|
Full Usage:
Objective
Field type: string
|
The specific task or objective the agent should accomplish
|
|
Desired output format
|
Full Usage:
Role
Field type: string
|
The agent's role and identity (e.g. "You are a financial analyst...")
|
Static members
| Static member |
Description
|
|
|
Nao