ToolComposition Type
A composed tool that chains, parallelizes, or conditionally routes between tools
Union cases
| Union case |
Description
|
|
|
|
Execute tools sequentially, passing output of one as input to next
|
|
|
|
|
|
Execute tools in parallel and collect all results
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAdaptive
Returns: bool
|
|
Full Usage:
this.IsChain
Returns: bool
|
|
Full Usage:
this.IsConditional
Returns: bool
|
|
Full Usage:
this.IsFallback
Returns: bool
|
|
Full Usage:
this.IsParallel
Returns: bool
|
|
Nao