Body Type
The document body: the single switch between the two fundamental document shapes. * `Fluid` — reflowable content (text / markdown / html). Paginated *targets* auto-break it into pages using `Document.DefaultPage`. * `Paged` — fixed pages / slides (pdf / word-as-laid-out / ppt). Fluid *targets* flatten the pages back into a single content stream.
Instance members
| Instance member |
Description
|
Full Usage:
this.IsFluid
Returns: bool
|
|
Full Usage:
this.IsPaged
Returns: bool
|
|
Nao