Converter Module
Top-level conversion helpers over a `ConverterRegistry`.
Functions and values
| Function or value |
Description
|
Full Usage:
Converter.convertBytes registry sourceMediaType targetMediaType ctx input
Parameters:
ConverterRegistry
sourceMediaType : string
targetMediaType : string
ctx : ConversionContext
input : byte[]
Returns: byte[]
|
Convert raw bytes from one media type to another, returning the produced bytes. Resources are extracted/resolved through `ctx`.
|
Full Usage:
Converter.convertFile registry sourceMediaType targetMediaType sourcePath targetPath
Parameters:
ConverterRegistry
sourceMediaType : string
targetMediaType : string
sourcePath : string
targetPath : string
|
Convert a file on disk to another format on disk, extracting media into a bundle directory alongside the output (defaults to the output's folder).
|
Nao