Placement Type
Per-child placement hints, interpreted according to the parent `Layout`. Fields irrelevant to the active layout are simply ignored.
Record fields
| Record Field |
Description
|
Cross-axis self-alignment override.
|
|
|
|
Full Usage:
Column
Field type: int option
|
1-based grid column the child starts in.
|
Full Usage:
ColumnSpan
Field type: int option
|
|
Full Usage:
Grow
Field type: float option
|
|
Full Usage:
Order
Field type: int option
|
|
Explicit rectangle within the container (absolute layout only).
|
|
Full Usage:
Row
Field type: int option
|
1-based grid row the child starts in.
|
Full Usage:
RowSpan
Field type: int option
|
|
Full Usage:
Shrink
Field type: float option
|
|
Static members
| Static member |
Description
|
|
|
Full Usage:
Placement.Cell(column, row, ?columnSpan, ?rowSpan)
Parameters:
int
row : int
?columnSpan : int
?rowSpan : int
Returns: Placement
|
Place a child in a grid cell with an optional span.
|
|
No placement hints — let the layout default-position the child.
|
Nao