Xlsx Module
Writer for Excel workbooks (`.xlsx`, `application/vnd.openxmlformats-officedocument.spreadsheetml.sheet`), backed by the DocumentFormat.OpenXml SDK. The document is flattened to rows on a single worksheet. There is no reader (spreadsheets are not a natural source for the prose model).
Types
| Type | Description |
|
Writes a `Document` as a single-sheet `.xlsx` workbook. |
Functions and values
| Function or value |
Description
|
Full Usage:
MediaType
Returns: string
|
|
Nao