PersistentTracer Type
Event-sourced ITracer. Span identifiers are generated internally, so this is a self-contained implementation (mirroring InMemoryTracer) that persists each span upsert as a full span snapshot and rebuilds the span table on load.
Constructors
| Constructor |
Description
|
|
|
Nao