WorkspaceRegistry Type
In-memory workspace registry backed by a concurrent dictionary. Designed to be registered as a singleton in the Orleans DI container.
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Register
Parameters:
WorkspaceId
defs : WorkspaceDefinitions
?sourcePath : string
|
Register a workspace with an optional source path for reload support
|
Nao